@@ -1,18 +1,20 @@
 #' @importFrom utils URLencode
 #' @importFrom shiny isRunning
+#' @importFrom data.table fread
 fread_antares <- function(opts, file, ...) {
   if (identical(opts$typeLoad, "api")) {
     file <- gsub("\\.txt$", "", file)
     response <- api_get(
       opts = opts,
       endpoint = I(file),
-      query = list(formatted = FALSE)
+      query = list(formatted = FALSE),
+      parse_result = "text"
     )
     suppressWarnings(
       tryCatch(fread(response, ...), error = function(e){
         if(isRunning())
           e <- as.character(e)
-        message(file) 
+        message(file)
         message(e)
       }))
   } else {
@@ -37,7 +39,7 @@ empty_strings_as_NA <- function(x) {
 
 
 #' @importFrom utils URLencode
-read_secure_json <- function(url, token = NULL, timeout = 60, config = list()) {
+read_secure_json <- function(url, token = NULL, timeout = 600, config = list()) {
   result <- api_get(
     opts = list(token = token, timeout = timeout, httr_config = config),
     endpoint = I(url)
@@ -47,7 +49,7 @@ read_secure_json <- function(url, token = NULL, timeout = 60, config = list()) {
 
 
 #' @importFrom httr GET timeout add_headers http_status
-.getSuccess <- function(path, token, timeout = 60, config = list()) {
+.getSuccess <- function(path, token, timeout = 600, config = list()) {
   if (!is.null(token) && token != "") {
     response <- GET(
       URLencode(path), timeout(timeout),
@@ -66,11 +68,11 @@ read_secure_json <- function(url, token = NULL, timeout = 60, config = list()) {
 #' @param opts
 #'   list of simulation parameters returned by the function
 #'   \code{\link{setSimulationPathAPI}}
-#' @param timeout \code{numeric} API timeout (seconds). Default to 60.
-#' 
+#' @param timeout \code{numeric} API timeout (seconds). Default to 600.
+#'
 #' @return
 #' Object of class `simOptions`, list of options used to read the data contained in the last
-#' simulation read by \code{\link{setTimeoutAPI}}.
+#' simulation read by \code{\link{setSimulationPathAPI}}.
 #'
 #' @export
 #'
@@ -95,6 +97,6 @@ is_api_study <- function(opts) {
 
 
 split_vector_in_equal_parts <- function(x, n) {
-  
+
   return(split(x, sort(seq(x)%%n)))
 }
